=======
History
=======

0.2.5 (2024-03-15)
------------------

- estimate_stationarity improvements
- python update


0.2.4 (2024-11-15)
------------------

- CascadeCase postprocessing headless plot fix
- CascadeCase postprocessing compare cases
- 97% test coverage

0.2.3 (2024-11-08)
------------------

- CascadeCase postprocessing plots
- parallelized pytests in CI and local
- 96% test coverage


0.2.2 (2024-10-31)
------------------

- hotfix nondimensionals: now compatible to more then just OpenFOAM simulations


0.2.1 (2024-10-30)
------------------

WITHDRAWN RELEASE (hotfix was incomplete)

- hotfix nondimensionals: now compatible to more then just OpenFOAM simulations


0.2.0 (2024-10-10)
------------------

- improved statistical le-te-extraction extraction with voxelization.
- new installation with pyproject.toml
- dependency upgrades
- python 3.11 support
- code cleanups and readme update


0.1.11 (2024-06-11)
------------------

- wake angle hotfix (gmsh cascadecase)


0.1.10 (2024-05-08)
------------------

- skeletonize le-te-extraction filter
- test improvements
- code cleanups and readme update


0.1.9 (2024-03-15)
------------------

- cascade_case refactoring
- cleanup
- le-te-extraction fix
- cascadebox meshing (gmsh)


0.1.8 (2023-10-31)
------------------

- bladeloading fix: reliable variable name usage


0.1.7 (2023-10-26)
------------------

- turbocascade fixes: usable meshing algorithm
- dependency updates


0.1.6 (2023-10-13)
------------------

WITHDRAWN RELEASE (incomplete meshing algorithm)

- productive meshing algorithm
- minor improvements


0.1.5 (2023-07-04)
------------------
- bugfixes alphashape
- initial gmsh intigration
- jupyternotebook testing
- improved codecov


0.1.4 (2023-06-25)
------------------
- cleaner structure, more reliability
- pypi deployment
- sphynx docs
- removed bugs


0.1.3 (2023-03-11)
------------------

* bug fixes
* implementation of a new timeseries stationarity analysis
* yplus postprocessing
* additional tests


0.1.2 (2022-20-12)
------------------

* meshquality methods
* example data sets
* jupyter notebook examples
